[Zope-Checkins] CVS: ZODB3/zdaemon - zdctl.py:1.35

Guido van Rossum guido@python.org
Sat, 25 Jan 2003 08:43:44 -0500


Update of /cvs-repository/ZODB3/zdaemon
In directory cvs.zope.org:/tmp/cvs-serv31279

Modified Files:
	zdctl.py 
Log Message:
Let an empty line report status.  This is handy.


=== ZODB3/zdaemon/zdctl.py 1.34 => 1.35 ===
--- ZODB3/zdaemon/zdctl.py:1.34	Fri Jan 24 13:06:02 2003
+++ ZODB3/zdaemon/zdctl.py	Sat Jan 25 08:43:41 2003
@@ -130,7 +130,9 @@
                     print "daemon's args =", args
 
     def emptyline(self):
-        pass # We don't want a blank line to repeat the last command
+        # We don't want a blank line to repeat the last command.
+        # Showing status is a nice alternative.
+        self.do_status()
 
     def send_action(self, action):
         """Send an action to the zdrun server and return the response.